package sgc.portal.base.persistence;

import sgc.portal.base.model.Yfvrprg;
import sgc.portal.base.util.EasyHashMap;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;


/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author mir(khjang @ sgc.co.kr)
 * @version 1.0.0
 * @since 2020. 8. 2.
 */
@Mapper
public interface ComBookMarkPopMapper {

    /**
     * Select book mark menu list.
     *
     * @param yfvrprgs the yfvrprgs
     * @return the list
     */
	//조회
    List<EasyHashMap<String, Object>> selectBookMarkMenu(Yfvrprg yfvrprgs);

    /**
     * Insert book mark menu int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void insertBookMarkMenu(Yfvrprg yfvrprgs);

    /**
     * Update book mark menu int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void updateBookMarkMenu(Yfvrprg yfvrprgs);

    /**
     * Delete book mark menu int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void deleteBookMarkMenu(Yfvrprg yfvrprgs);
    
    /**
     * Insert book mark Prg int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void insertBookMarkPrg(Yfvrprg yfvrprgs);

    /**
     * Update book mark Prg int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void updateBookMarkPrg(Yfvrprg yfvrprgs);

    /**
     * Delete book mark Prg int.
     *
     * @param yfvrprgs the yfvrprgs
     */
    void deleteBookMarkPrg(Yfvrprg yfvrprgs);
}

